<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear Picture Show plugin.
# Copyright (c) 2008 Anne-Cécile Calvot. All rights reserved.
#
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# ***** END LICENSE BLOCK *****

/**
 * Permet d'ordoner un tableau d'image en fonction d'un fichier texte, l'ordre peut se retrouver modifié
 * en fonction des images réellement présentes.
 * Permet aussi de sauvegarder un nouvel ordre.
 */
class psAdminSchedulerPicture extends psSchedulerPicture {
	
	/**
	  * Sauvegarde dans le fichier picturesShow.txt un tableau représentant l'ordre ainsi que le selection à appliquer aux images.
	  *
	  * $order : Un tableau ordonné dont les clées sont le nom de l'image; et la valeur un tableau
	  * à deux éléments : selection et nom_image.
	  * selection peut prendre comme valeur : "+" ou "-" qui signifie respectivement selectionné, non selectionné.
	  */
	public function saveOrder($order) {
		//écriture depuis début du fichier
		$file = psMedia::getRootDevPath(false)."/".$this->rep_gallery."/".parent::$file_name;
		if (!file_exists($file) || is_writable($file)) {
			$fp = fopen($file,"wb");

			if(isset($fp)) {
				if (!empty($order))
				{
					foreach ($order as $val) {
						if (fwrite($fp, $val[0].$val[1]."\n") === FALSE) {
							throw new Exception(__("Can not write in the file")." ".$file.".");
						}
					}
				}
				else {
					//vide le fichier
				}
				fflush($fp);
			}
			fclose($fp);
			
			$this->order = $order;
		}
		else {
			throw new Exception(__("Can not write in the file")." ".$file.".");
		}
	}

	/**
	 * On modifie ordre en fonction des images que l'on trouve ou trouve pas.
	 * L'ordre n'est pas sauvegarder dans le fichier, on attend la validation de l'utilisateur.
	 * $pictures : {array(psPicture)} avec en clé le nom/id de l'image
	 * @return un tableau ordonné de psPictures 
	 */
	public function applyOrder($pictures) {
		$new_pictures = array();
		$tmp_pictures = $pictures;
		foreach($this->order as $picture_id => &$info) {
			if(array_key_exists($picture_id,$tmp_pictures)) {
				
				if($info[0] == "-") {
					$tmp_pictures[$picture_id]->setIsSelected(false);
				}
				else if($info[0] == "+") {
					$tmp_pictures[$picture_id]->setIsSelected(true);
				}
				$new_pictures[$picture_id] = $tmp_pictures[$picture_id];
				unset($tmp_pictures[$picture_id]);
			}
			else {
				unset($this->order[$picture_id]);
			}
		}
		
		if(count($tmp_pictures) != 0 ) {
			foreach($tmp_pictures as $picture_id => &$picture) {
				$new_pictures[$picture_id] = $tmp_pictures[$picture_id];
				$this->order[$picture_id][]=($picture->getIsSelected())?"+":"-";
				$this->order[$picture_id][]=$picture->getId();
			}
		}
		
		return  $new_pictures;
	}
	
}
?>
