<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear Picture Show plugin.
# Copyright (c) 2008 Anne-Cécile Calvot. All rights reserved.
#
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# ***** END LICENSE BLOCK *****
/**
 * Permet d'ordoner un tableau d'image en fonction d'un fichier texte.
 * L'ordre ne peut être changé.
 */
class psSchedulerPicture {

	protected static $file_name = "picturesShow.txt";
	
	protected $rep_gallery; #  {String}
	protected $order = array();
	
	public function __construct($rep_gallery)
	{
		$this->rep_gallery = $rep_gallery;
		$this->loadOrder();
	}

	/**
	  * Charge à partir du fichier picturesShow.txt un tableau représentant l'ordre ainsi
	  * que la selection à appliquer aux images.
	  *
	  * @return Un tableau ordonné dont les clées sont le nom de l'image; et la valeur un tableau
	  * à deux éléments : selection et nom_image.
	  * selection peut prendre comme valeur : "+" ou "-" qui signifie respectivement selectionné, non selectionné.
	  */
	protected function loadOrder() {
		# lecture depuis début du fichier
		$this->order = array();
		$filename = psMedia::getRootDevPath(false)."/".$this->rep_gallery."/".self::$file_name;
		if(file_exists($filename)) {
			$fp = fopen($filename,"r");
			if(isset($fp)) {
				while(!feof($fp)) {
					# On récupère une ligne
					$ligne = fgets($fp,255);
					if (trim($ligne,"\r\n")!="") {
						$val = substr(trim($ligne,"\r\n"),1);
						$select = substr($ligne,0,1);
						$this->order[$val] = array($select,$val);
					}
				}
			}
			fclose($fp); # On ferme le fichier
		}
	}

	/**
	 * On applique l'ordre sur les images, les images dont l'ordre n'est pas précisé sont rajouté à la fin.
	 * $pictures : {array(psPicture)} avec en clé le nom/id de l'image
	 * @return un tableau ordonné de psPictures 
	 */
	public function applyOrder($pictures) {
		$new_pictures = array();
		$tmp_pictures = $pictures;
		foreach($this->order as $picture_id => &$info) {
			if(array_key_exists($picture_id,$tmp_pictures)) {
				
				if($info[0] != "-") {
					$new_pictures[$picture_id] = $tmp_pictures[$picture_id];
				}
				unset($tmp_pictures[$picture_id]);
			}
		}
		
		if(count($tmp_pictures) != 0 ) {
			$new_pictures = $new_pictures + $tmp_pictures;
		}

		return  $new_pictures;
	}
	
}
?>
