<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear Picture Show plugin.
# Copyright (c) 2008 Anne-Cécile Calvot. All rights reserved.
#
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# ***** END LICENSE BLOCK *****

/**
 * Classe regroupant les différents formats d'une même image.
 */
class psPicture {
	private $id;				// <b>string</b> l'identifiant
	private $is_selected;		// <b>boolean</b> à true si l'image à été choisie pour être vu dans le blog
	private $thumbnails=array();	// <b>array{psThumbnail}</b> liste des miniatures + originale

	public function __construct($id)
	{
		$this->id = $id;
		$this->is_selected = true;
	}

	/**
	 * Rajout un format à l'image.
	 * $thumbnail	<b>psFormat</b> le format à rajouter
	 */
	public function addThumbnail($thumbnail)
	{
		if ($thumbnail->getFormat() === psFormatsTools::$original_pitures_format_id)
		{
			$this->thumbnails[$thumbnail->getFormat()]=$thumbnail;
		}
		else
		{
			$this->thumbnails[$thumbnail->getFormat()->getId()] = $thumbnail;
		}
	}

	public function getId()
	{
		return $this->id;
	}

	public function getIsSelected()
	{
		return $this->is_selected;
	}

	public function setIsSelected($is_selected)
	{
		$this->is_selected = $is_selected;
	}

	public function getThumbnailByFormatId($format_id)
	{
		if (isset($this->thumbnails[$format_id]))
		{
			return $this->thumbnails[$format_id];
		}
		return null;
	}

	public function formatExist($format)
	{
		if ($format === psFormatsTools::$original_pitures_format_id)
		{
			return isset($this->thumbnails[$format]);
		}
		elseif (is_object($format))
		{
			return isset($this->thumbnails[$format->getId()]);
		}
		else
		{
			return isset($this->thumbnails[$format]);
		}
	}
}

?>
