<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear Format Plus plugin.
# Copyright (c) 2008 Anne-Cécile Calvot. All rights reserved.
#
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# ***** END LICENSE BLOCK *****
/**
 * Interface utilisée par les plugins qui voudront utiliser F+ 
 * devant toujours être rétrocompatible et assez peu modifiée
 * (ajout de fonctionnalité).
 *
 * Cette classe permet : 
 *   - d'obtenir la liste de tous les formats
 */
class fpFFormatLibrary {

	/**
	 * Methode Outil permettant à l'interface d'étre indépendante de la présence ou non
	 * du plugin F+.
	 */
	private static function getAllDefaultFormats($class_format_name) {
		$g_core = &$GLOBALS['core'];
		$formats = array();

		// on fait une initialisation pseudo dynamique par rapport
		// au gestionnaire de média de DC2
		if ($g_core->media == null) {
			$g_core->media = new dcMedia($g_core);
		}
		if ($g_core->media->thumb_tp == '%s/.%s_%s.jpg') {
			foreach ($g_core->media->thumb_sizes as $key => $info) {
				$class = new ReflectionClass($class_format_name);
				if ($class->isInstantiable()) {
				    $formats[$key]= $class->newInstance($key, $info[2],'\.(.+)_('.$key.')',1);
				}
				
			}
		}
		return $formats;
	}

	/**
	 * Permet d'obtenir la liste des des formats utilisable, en fonction ou non de :
	 *   - la présence ou non de F+
	 *   - du format demandé
	 *
	 * $class_format_name : la classe du format attendu en retour
	 */
	public static function getAllFormats($class_format_name){
		$g_core = &$GLOBALS['core'];

		$media = self::getAllDefaultFormats($class_format_name);
		$user = array();
		if ($g_core->plugins->moduleExists("formatPlus") === true) {
			$user = fpFormatLibrary::getUserPicturesFormat($class_format_name);
		}
		if (count($user) == 0 && count($media) == 0) {
			return array();
		}
		else if (count($user) == 0) {
			return $media;
		}
		else if (count($media) == 0) {
			return $user;
		}
		return $media + $user;
	}
}
?>
